@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 368 2008-03-07 03:19:54Z fishbone $
+ * @version    SVN: $Id: m3Func.php 1066 2008-10-10 05:48:07Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -296,4 +296,24 @@ function parseUrlParam($src)
 	}
 	return $dest;
 }
+/**
+ * 文字列メモリ表現から数値メモリ表現を取得
+ *
+ * @param string $val			メモリ文字列表現
+ * @return int					メモリバイト数
+ */
+function convBytes($val)
+{
+	$val = trim($val);
+	$last = strtolower($val{strlen($val) -1});
+	switch($last){
+		case 'g':
+			$val *= 1024;
+		case 'm':
+			$val *= 1024;
+		case 'k':
+			$val *= 1024;
+	}
+	return $val;
+}
 ?>
