@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: pageManager.php 1072 2008-10-11 10:30:30Z fishbone $
+ * @version    SVN: $Id: pageManager.php 1112 2008-10-24 03:15:05Z fishbone $
  * @link       http://www.magic3.org
  */
 class PageManager
@@ -38,7 +38,6 @@ class PageManager
 	private $viewPosId = array();		// テンプレート上のポジションのタグID
 	private $updateParentWindow;		// 親ウィンドウを再描画するかどうか
 	private $updateDefSerial;			// 更新する項目のページ定義シリアル番号
-	private $useMootools;				// MootoolsをPrototypeの代わりに使用するかどうか
 	private $headDescription;				// HTMLヘッダ「description」に出力する文字列
 	private $headKeywords;				// HTMLヘッダ「keywords」に出力する文字列
 	private $headCss = array();			// HTMLヘッダにCSS出力する文字列
@@ -46,6 +45,7 @@ class PageManager
 	private $lastHeadCss;				// 最後に設定したHTMLヘッダにCSS出力する文字列
 	private $lastHeadScript;			// 最後に設定したHTMLヘッダにJavascript出力する文字列
 	private $outputHead;				// HTMLヘッダ出力を行ったかどうか
+	private $isAbort;					// ページ作成処理を中断するかどうか
 	private $libFiles;					// javascript追加用ライブラリ
 	private $pageDefRev = 234;				// 画面定義のリビジョン番号
 	const ADMIN_WIDGET_ID = 'admin_main';		// 管理用ウィジェットのウィジェットID
@@ -283,13 +283,13 @@ class PageManager
 		$this->hasScriptCache = $status;
 	}
 	/**
-	 * MootoolsをPrototypeの代わりに使用するかどうか
+	 * ページ作成処理を中断するかどうかを取得
 	 *
-	 * @return 				なし
+	 * @return bool		true=中断、false=継続
 	 */
-	function useMootools()
+	function isPageAbort()
 	{
-		$this->useMootools = true;
+		return $this->isAbort;
 	}
 	/**
 	 * 親ウィンドウを再描画
@@ -354,7 +354,7 @@ class PageManager
 	 * @param RequestManager $request		HTTPリクエスト処理クラス
 	 * @return 								なし
 	 */
-	function start($request)
+	function startPage($request)
 	{
 		global $gEnvManager;
 		global $gRequestManager;
@@ -463,12 +463,15 @@ class PageManager
 	 * @param bool $getOutput				出力を取得するかどうか
 	 * @return string        				最終出力HTML
 	 */
-	function end($request, $getOutput = false)
+	function endPage($request, $getOutput = false)
 	{
 		global $gAjaxManager;
 		global $gRequestManager;
 		global $gInstanceManager;
-
+		
+		// ページ作成処理を中断するかどうか
+		if ($this->isAbort) return '';
+		
 		$contents = '';
 		
 		// 実行コマンドを取得
@@ -482,7 +485,7 @@ class PageManager
 				echo $this->getLastContents($request);
 			}
 		}
-
+		
 		// セッションへユーザ情報を保存
 		$userInfo = $gInstanceManager->getUserInfo();
 		$gRequestManager->setSessionValueWithSerialize(M3_SESSION_USER_INFO, $userInfo);
@@ -511,6 +514,40 @@ class PageManager
 		}
 		return $contents;
 	}
+	/**
+	 * ページ作成処理中断
+	 *
+	 * @return 							なし
+	 */
+	function abortPage($callback = null)
+	{
+		global $gInstanceManager;
+		global $gRequestManager;
+		
+		// exit()等でabortPage()が最後の処理になってしまう可能性があるのでなるべく必要な処理を行う
+		ob_end_clean();
+		
+		// セッションへユーザ情報を保存
+		$userInfo = $gInstanceManager->getUserInfo();
+		$gRequestManager->setSessionValueWithSerialize(M3_SESSION_USER_INFO, $userInfo);
+		
+		$this->isAbort = true;					// ページ作成処理を中断するかどうか
+	}
+	/**
+	 * 強制終了を実行
+	 *
+	 * @return 		なし
+	 */
+	function exitSystem()
+	{
+		global $gEnvManager;
+		global $gAccessManager;
+		
+		// DBが使用可能であれば、アクセスログのユーザを登録
+		if ($gEnvManager->canUseDb()) $gAccessManager->accessLogUser();
+		
+		exit;
+	}
 	/**
 	 * 遅延ウィジェット実行
 	 *
@@ -1238,7 +1275,8 @@ class PageManager
 				// ウィジェットを実行
 				$count = count($this->pageDefRows);
 				for ($i = 0; $i < $count; $i++){
-					$this->pageDefLoop($i, $this->pageDefRows[$i]);
+					$ret = $this->pageDefLoop($i, $this->pageDefRows[$i]);
+					if (!$ret) return;		// 処理中断のときは終了
 				}
 			
 				if ($position == 'main'){		// メイン部のときは、メッセージを出力
@@ -1534,6 +1572,7 @@ class PageManager
 	 * @param int $index			行番号
 	 * @param array $fetchedRow		fetch取得した行
 	 * @param array $param    		任意パラメータ
+	 * @return bool					処理を中断するかどうか
 	 */
 	function pageDefLoop($index, $fetchedRow)
 	{
@@ -1543,6 +1582,9 @@ class PageManager
 //		$style = 1;
 		$style = 0;
 
+		// ページ作成中断のときは終了
+		if ($this->isAbort) return false;
+		
 		// ウィジェットID取得
 		$widgetId = $fetchedRow['wd_id'];		
 		$widgetIndexFile = $gEnvManager->getWidgetsPath() . '/' . $widgetId . '/index.php';
