@@ -7,7 +7,7 @@
 DROP TABLE IF EXISTS commerce_config;
 CREATE TABLE commerce_config (
     cg_id                VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ID(Key)
-    cg_value             TEXT           DEFAULT ''                    NOT NULL,      -- 値
+    cg_value             TEXT                                         NOT NULL,      -- 値
     cg_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 名称
     cg_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
     cg_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
@@ -97,7 +97,7 @@ CREATE TABLE tax_type (
     tt_tax_rate_id       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 税率ID
     tt_name              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 名称
     tt_description       VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 説明
-    tt_geo_zone_id       TEXT           DEFAULT ''                    NOT NULL,      -- 対象区域(,区切り)
+    tt_geo_zone_id       TEXT                                         NOT NULL,      -- 対象区域(,区切り)
     tt_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
     PRIMARY KEY          (tt_id,        tt_language_id)
 ) TYPE=innodb;
@@ -199,7 +199,7 @@ CREATE TABLE product_image (
     im_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     im_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 画像名
-    im_url               TEXT           DEFAULT ''                    NOT NULL,      -- URL
+    im_url               TEXT                                         NOT NULL,      -- URL
     
     im_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
     im_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
@@ -293,9 +293,9 @@ CREATE TABLE pay_method_def (
     po_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     po_name              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 名称
-    po_description       TEXT           DEFAULT ''                    NOT NULL,      -- 説明
+    po_description       TEXT                                         NOT NULL,      -- 説明
     po_iwidget_id        VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- インナーウィジェットID(ファイル名)
-    po_param             TEXT           DEFAULT ''                    NOT NULL,      -- 設定インナーウィジェット用パラメータ
+    po_param             TEXT                                         NOT NULL,      -- 設定インナーウィジェット用パラメータ
     po_index             INT            DEFAULT 0                     NOT NULL,      -- 表示順(1～)
     po_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 項目を表示するかどうか
     
@@ -323,9 +323,9 @@ CREATE TABLE delivery_method_def (
     do_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
     
     do_name              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 名称
-    do_description       TEXT           DEFAULT ''                    NOT NULL,      -- 説明
+    do_description       TEXT                                         NOT NULL,      -- 説明
     do_iwidget_id        VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- インナーウィジェットID(ファイル名)
-    do_param             TEXT           DEFAULT ''                    NOT NULL,      -- 設定インナーウィジェット用パラメータ
+    do_param             TEXT                                         NOT NULL,      -- 設定インナーウィジェット用パラメータ
     do_index             INT            DEFAULT 0                     NOT NULL,      -- 表示順(1～)
     do_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 項目を表示するかどうか
     
@@ -531,7 +531,7 @@ CREATE TABLE product (
     pt_description_short VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 商品説明(簡易)
     pt_admin_note        VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 管理者用備考
     pt_category_id       INT            DEFAULT 0                     NOT NULL,      -- 商品カテゴリーID
-    pt_related_product   TEXT           DEFAULT ''                    NOT NULL,      -- 関連商品ID(,区切り)
+    pt_related_product   TEXT                                         NOT NULL,      -- 関連商品ID(,区切り)
     pt_manufacturer_id   INT            DEFAULT 0                     NOT NULL,      -- メーカーID
     pt_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
     pt_default_price     VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 優先する価格タイプ
@@ -539,7 +539,7 @@ CREATE TABLE product (
     pt_head_description  VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- HTMLヘッダ「description」
     pt_head_keywords     VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- HTMLヘッダ「keywords」
     pt_search_keyword    VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 検索キーワード(「,」区切り)
-    pt_site_url          TEXT           DEFAULT ''                    NOT NULL,      -- 詳細情報のサイト
+    pt_site_url          TEXT                                         NOT NULL,      -- 詳細情報のサイト
     pt_unit_type_id      VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- 販売の基準となる単位種別
     pt_unit_quantity     DECIMAL(5,2)   DEFAULT 0                     NOT NULL,      -- 1販売単位となる数量
     pt_innner_quantity   INT            DEFAULT 0                     NOT NULL,      -- 1販売単位に含まれる製品数量(入数)
@@ -548,10 +548,10 @@ CREATE TABLE product (
     pt_weight            DECIMAL(5,2)   DEFAULT 0                     NOT NULL,      -- 重量(kg)-配送時の送料算出に使用
     pt_tax_type_id       VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 税種別ID
     
-    pt_attr_menu         TEXT           DEFAULT ''                    NOT NULL,      -- 商品タイプが単品商品(親子なし)の場合の商品属性選択メニュー(メニュー間区切り「;」、メニュー内区切り「,」)
+    pt_attr_menu         TEXT                                         NOT NULL,      -- 商品タイプが単品商品(親子なし)の場合の商品属性選択メニュー(メニュー間区切り「;」、メニュー内区切り「,」)
     pt_parent_id         INT            DEFAULT 0                     NOT NULL,      -- 商品タイプが単品商品(親子)の場合の商品親ID
-    pt_attr_condition    TEXT           DEFAULT ''                    NOT NULL,      -- 商品タイプが単品商品(親子)の場合の商品属性の条件(,区切り)
-    pt_product_set       TEXT           DEFAULT ''                    NOT NULL,      -- 商品タイプがセット商品の場合の組み合わせ商品ID(,区切り)
+    pt_attr_condition    TEXT                                         NOT NULL,      -- 商品タイプが単品商品(親子)の場合の商品属性の条件(,区切り)
+    pt_product_set       TEXT                                         NOT NULL,      -- 商品タイプがセット商品の場合の組み合わせ商品ID(,区切り)
     pt_option_price      VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプがオプション商品の場合の価格設定
     
     pt_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
@@ -694,11 +694,11 @@ CREATE TABLE `order_sheet` (
     oe_card_number       VARCHAR(32)    DEFAULT ''                    NOT NULL,      -- クレジットカード番号
     oe_card_expires      VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- クレジットカード期限
 
-    oe_message           TEXT           DEFAULT ''                    NOT NULL,      -- 取引先からのメッセージ
-    oe_note              TEXT           DEFAULT ''                    NOT NULL,      -- 補足情報
-    oe_option_fields     TEXT           DEFAULT ''                    NOT NULL,      -- 追加フィールド(「,」区切り)
+    oe_message           TEXT                                         NOT NULL,      -- 取引先からのメッセージ
+    oe_note              TEXT                                         NOT NULL,      -- 補足情報
+    oe_option_fields     TEXT                                         NOT NULL,      -- 追加フィールド(「,」区切り)
     oe_demand_dt         DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 希望納期(日付)
-    oe_demand_time       TEXT           DEFAULT ''                    NOT NULL,      -- 希望納期(時間帯)
+    oe_demand_time       TEXT                                         NOT NULL,      -- 希望納期(時間帯)
     oe_appoint_dt        DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 予定納期
     
     oe_currency_id       VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 通貨ID
@@ -771,11 +771,11 @@ CREATE TABLE order_header (
     or_card_number       VARCHAR(32)    DEFAULT ''                    NOT NULL,      -- クレジットカード番号
     or_card_expires      VARCHAR(4)     DEFAULT ''                    NOT NULL,      -- クレジットカード期限
 
-    or_message           TEXT           DEFAULT ''                    NOT NULL,      -- 取引先からのメッセージ
-    or_note              TEXT           DEFAULT ''                    NOT NULL,      -- 補足情報
-    or_option_fields     TEXT           DEFAULT ''                    NOT NULL,      -- 追加フィールド(「,」区切り)
+    or_message           TEXT                                         NOT NULL,      -- 取引先からのメッセージ
+    or_note              TEXT                                         NOT NULL,      -- 補足情報
+    or_option_fields     TEXT                                         NOT NULL,      -- 追加フィールド(「,」区切り)
     or_demand_dt         DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 希望納期(日付)
-    or_demand_time       TEXT           DEFAULT ''                    NOT NULL,      -- 希望納期(時間帯)
+    or_demand_time       TEXT                                         NOT NULL,      -- 希望納期(時間帯)
     or_appoint_dt        DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 予定納期
     
     or_currency_id       VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 通貨ID
@@ -838,8 +838,8 @@ CREATE TABLE order_detail (
 
     od_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
     od_product_name      VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 商品名
-    od_attribute         TEXT           DEFAULT ''                    NOT NULL,      -- 商品属性(属性メニューの選択値)
-    od_note              TEXT           DEFAULT ''                    NOT NULL,      -- 補足情報
+    od_attribute         TEXT                                         NOT NULL,      -- 商品属性(属性メニューの選択値)
+    od_note              TEXT                                         NOT NULL,      -- 補足情報
 
     od_unit_price        DECIMAL(15,4)  DEFAULT 0                     NOT NULL,      -- 受注単価(税抜)
     od_price_with_tax    DECIMAL(15,4)  DEFAULT 0                     NOT NULL,      -- 受注単価(税込み)
@@ -900,7 +900,7 @@ CREATE TABLE stock_plan (
     sp_plan_type         INT            DEFAULT 0                     NOT NULL,      -- 入出庫区分(1=入庫、2=出庫、3=棚卸)
     sp_customer_id       INT            DEFAULT 0                     NOT NULL,      -- 予定取引先
     sp_quantity          INT            DEFAULT 0                     NOT NULL,      -- 個数
-    sp_note              TEXT           DEFAULT ''                    NOT NULL,      -- 補足情報
+    sp_note              TEXT                                         NOT NULL,      -- 補足情報
 
     sp_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
     sp_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
