@@ -32,6 +32,10 @@ INSERT INTO currency (cu_id, cu_language_id, cu_name, cu_description, cu_symbol,
 INSERT INTO currency (cu_id, cu_language_id, cu_name, cu_description, cu_symbol, cu_post_symbol, cu_decimal_place, cu_index) VALUES ('HKD', 'ja', 'ドル',       '香港ドル',             '',   'ドル',       2, 17);
 INSERT INTO currency (cu_id, cu_language_id, cu_name, cu_description, cu_symbol, cu_post_symbol, cu_decimal_place, cu_index) VALUES ('TRL', 'ja', 'リラ',       'トルコリラ',           '',   'リラ',       0, 18);
 
+-- Wiki設定マスター
+INSERT INTO wiki_config (wg_id,        wg_value,     wg_name,                 wg_index)
+VALUES                  ('password',   md5('admin'), '共通パスワード',        1);
+
 -- ブログ設定マスター
 INSERT INTO blog_config (bg_id,              bg_value,    bg_name,                     bg_index)
 VALUES                 ('receive_comment',   '0',         'コメントの受け付け',        1);
@@ -149,8 +153,8 @@ DELETE FROM _widgets WHERE wd_id = 'custom_header';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('custom_header',     'カスタムヘッダ',           'DFHT', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'ヘッダ部分で画像やサイトのタイトル文字列をカスタマイズ。',          false,           false,       true,         true,        true,        false,               false,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'ec_login_box';
-INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
-('ec_login_box',       'Eコマース - ログイン',       'ELOG', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Eコマースの会員ログイン用ボックス。',          false,           false,       true,         true,        false,        false,               false,true,           100, now(), now());
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('ec_login_box',       'Eコマース - ログイン',       'ELOG', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Eコマースの会員ログイン用ボックス。', 'md5',         false,           false,       true,         true,        false,        false,               false,true,           100, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'custom_footer';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('custom_footer',     'カスタムフッタ',           'CSFT', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'フッタ部に表示し、著作権等の表示を行う。',          false,           false,       true,         true,        true,        false,               false,true,           0, now(), now());
@@ -235,8 +239,8 @@ DELETE FROM _widgets WHERE wd_id = 'bbs_main';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('bbs_main',          '掲示板 - メイン',            'BBMA', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, '掲示板の投稿記事を表示。',         false,           false,       true,         true,        true,        false,               false,true,               0, now(),    now());
 DELETE FROM _widgets WHERE wd_id = 'bbs_login_box';
-INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
-('bbs_login_box',         '掲示板 - ログイン',            'BBML', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, '掲示板の会員ログイン用ボックス。',         false,           false,       true,         true,        false,        false,               false,true,               100, now(),    now());
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('bbs_login_box',         '掲示板 - ログイン',            'BBML', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, '掲示板の会員ログイン用ボックス。', 'md5',        false,           false,       true,         true,        false,        false,               false,true,               100, now(),    now());
 DELETE FROM _widgets WHERE wd_id = 'contactus';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('contactus',          'お問い合わせメール送信',            'CONU', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'お問い合わせの入力データをメールで送る。',          false,           false,       true,         true,        true,        false,               false,true,               0, now(),    now());
@@ -289,8 +293,8 @@ DELETE FROM _widgets WHERE wd_id = 'g_qrcode';
 INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
 ('g_qrcode',     'Google QRコード',           '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Google APIを使ったQRコード表示。',         false,           false,       true,         true,        true,        false,               true,true,           0, now(), now());
 DELETE FROM _widgets WHERE wd_id = 'wiki_main';
-INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib_a, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
-('wiki_main',          'Wiki - メイン',            '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Wikiを表示する。', '',          false,           false,       true,         true,        true,        false,               false,true,               0, now(),    now());
+INSERT INTO _widgets (wd_id, wd_name, wd_type, wd_version, wd_params, wd_author, wd_copyright, wd_license, wd_official_level, wd_description, wd_add_script_lib, wd_add_script_lib_a, wd_read_scripts, wd_read_css, wd_available, wd_editable, wd_has_admin, wd_enable_operation, wd_use_instance_def, wd_is_initialized, wd_launch_index, wd_install_dt, wd_create_dt) VALUES
+('wiki_main',          'Wiki - メイン',            '', '1.0.0',  '',        'Naoki Hirata', 'Magic3.org', 'GPL', 10, 'Wikiを表示する。(実装中)', 'md5', 'md5',         false,           true,       true,         true,        true,        false,               false,true,               0, now(),    now());
 
 -- ウィジェット情報(携帯用)
 DELETE FROM _widgets WHERE wd_id = 'm/sample';
