@@ -468,52 +468,6 @@ function m3_hideImageToolTip()
 {
 	document.getElementById('image_tooltip').style.display = 'none';
 }
-/**
- * 画像ファイルブラウザを表示
- *
- * @return なし
- */
-function m3_openImageFileBrowser()
-{
-	var imageConnector = 'connectors/php/connector.php';
-	var imageBrowser = M3_ROOT_URL + '/scripts/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/browser.html?Type=Image&Lang=ja&Connector=' + imageConnector;
-	var sOptions = "toolbar=no,status=no,resizable=yes,dependent=yes,scrollbars=yes";
-	var screenWidth, screenHeight;
-	var width, height;
-	try
-	{
-		screenWidth	= screen.width;
-		screenHeight	= screen.height;
-	} catch (e){
-		screenWidth		= 800;
-		screenHeight	= 600;
-	}
-	width	= screenWidth * 0.7;
-	height	= screenHeight * 0.7;
-	window.open(imageBrowser, 'FCKBrowseWindow', sOptions + ",width=" + width + ",height=" + height);
-}
-/**
- * TextAreaをHTMLエディターに変更
- *
- * @param string id			TextAreaタグのIDまたはname
- * @param bool	isMobile	携帯用のツールバー表示
- * @return なし
- */
-function m3_setHtmlEditor(id, isMobile)
-{
-	var oFCKeditor		= new FCKeditor(id);
-	oFCKeditor.BasePath	= M3_ROOT_URL + '/scripts/fckeditor2.6/';
-	oFCKeditor.Config['CustomConfigurationsPath'] = M3_ROOT_URL + '/scripts/m3/fckconfig.js';
-	if (isMobile == null || isMobile == false){
-		oFCKeditor.ToolbarSet	= "M3Default";			// ツールバーリソース名
-	} else {
-		oFCKeditor.ToolbarSet	= "M3MobileDefault";	// ツールバーリソース名
-	}
-	oFCKeditor.Width	= "100%";
-	oFCKeditor.Height	= "100%";
-	oFCKeditor.Value	= 'This is some <strong>sample text<\/strong>. You are using <a href="http://www.fckeditor.net/">FCKeditor<\/a>.';
-	oFCKeditor.ReplaceTextarea();
-}
 String.prototype.trim = function() {
 	return this.replace(/^\s+|\s+$/g, "");
 }
