@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installInitdbWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
+ * @version    SVN: $Id: _installInitdbWidgetContainer.php 1054 2008-10-02 09:51:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -40,26 +40,21 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$this->sysDb = $gInstanceManager->getSytemDbObject();
 		
 		// 実行SQLスクリプトファイルの定義
-		$i = 0;
-		$this->createTableScripts[$i]['filename']		= 'mysql_create_base.sql';		// ファイル名
-		$this->createTableScripts[$i]['name']			= 'システム基本テーブル作成';		// 表示名
-		$this->createTableScripts[$i]['description']		= 'システムで最小限必要なテーブルの作成';		// 説明
-		$i++;
-		$this->createTableScripts[$i]['filename']		= 'mysql_insert_base.sql';		// ファイル名
-		$this->createTableScripts[$i]['name']			= 'システム基本データ登録';		// 表示名
-		$this->createTableScripts[$i]['description']		= 'システムで最小限必要なデータの登録';		// 説明
-		$i++;
-		$this->createTableScripts[$i]['filename']		= 'mysql_create_standard.sql';		// ファイル名
-		$this->createTableScripts[$i]['name']			= 'システム標準テーブル作成';		// 表示名
-		$this->createTableScripts[$i]['description']		= 'システムを通常使用するのに必要なテーブルの作成';		// 説明
-		$i++;
-		$this->createTableScripts[$i]['filename']		= 'mysql_insert_standard.sql';		// ファイル名
-		$this->createTableScripts[$i]['name']			= 'システム標準データ登録';		// 表示名
-		$this->createTableScripts[$i]['description']		= 'システムを通常使用するのに必要なデータの登録';		// 説明
-		$i++;
-		$this->createTableScripts[$i]['filename']		= 'mysql_create_ec.sql';		// ファイル名
-		$this->createTableScripts[$i]['name']			= 'Eコマース用テーブル';		// 表示名
-		$this->createTableScripts[$i]['description']		= 'Eコマース用テーブルの作成';		// 説明
+		$this->createTableScripts = array(	array(	'filename' 		=> 'mysql_create_base.sql',					// ファイル名
+													'name'			=> 'システム基本テーブル作成',				// 表示名
+													'description'	=> 'システムで最小限必要なテーブルの作成'),	// 説明
+											array(	'filename' 		=> 'mysql_insert_base.sql',					// ファイル名
+													'name'			=> 'システム基本データ登録',				// 表示名
+													'description'	=> 'システムで最小限必要なデータの登録'),	// 説明
+											array(	'filename' 		=> 'mysql_create_standard.sql',					// ファイル名
+													'name'			=> 'システム標準テーブル作成',				// 表示名
+													'description'	=> 'システムを通常使用するのに必要なテーブルの作成'),	// 説明
+											array(	'filename' 		=> 'mysql_insert_standard.sql',					// ファイル名
+													'name'			=> 'システム標準データ登録',				// 表示名
+													'description'	=> 'システムを通常使用するのに必要なデータの登録'),	// 説明
+											array(	'filename' 		=> 'mysql_create_ec.sql',					// ファイル名
+													'name'			=> 'Eコマース用テーブル',				// 表示名
+													'description'	=> 'Eコマース用テーブルの作成'));	// 説明
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -94,28 +89,19 @@ class _installInitdbWidgetContainer extends BaseWidgetContainer
 		$type = $request->trimValueOf('install_type');
 		if ($act == ''){
 		} else if ($act == 'done'){
-			// SQLスクリプトを実行
+			// ##### SQLスクリプトを実行 #####
 			for ($i = 0; $i < count($this->createTableScripts); $i++){
 				$ret = $gDbManager->execInitScriptFile($this->createTableScripts[$i]['filename'], $errors);
 				if (!$ret) break;// 異常終了の場合
 			}
-			// 初期データ登録
+			
+			// ##### 初期データ登録 #####
 			$serverId = md5($gEnvManager->getRootUrl() . time());		// サーバID
 			$now = date("Y/m/d H:i:s");	// 現在日時
 			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::SERVER_ID, $serverId);
 			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::INSTALL_DT, $now);
 			if ($ret) $ret = $this->sysDb->updateSystemConfig(self::WORK_DIR, M3_SYSTEM_WORK_DIR_PATH);// 一時ディレクトリ
 			
-			/*
-			// DB初期化実行
-			if ($type == 'base'){
-				$ret = $gDbManager->execInitScript(0, $errors);		// 基本テーブル
-			} else if ($type == 'all'){
-				$ret = $gDbManager->execInitScript(0, $errors);// 基本テーブル
-				if ($ret) $ret = $gDbManager->execInitScript(1, $errors);// 標準テーブル
-				if ($ret) $ret = $gDbManager->execInitScript(2, $errors);// ECテーブル
-			}*/
-			
 			if ($ret){// 正常終了の場合
 				$gPageManager->redirect('?task=initother&install_type=' . $type);
 			} else {
