@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
+ * @version    SVN: $Id: admin_mainConfigsysWidgetContainer.php 1070 2008-10-11 06:39:03Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -220,6 +220,13 @@ class admin_mainConfigsysWidgetContainer extends BaseWidgetContainer
 			$data = 'off';
 		}
 		$this->tmpl->addVar("_widget","current_mbstring", $data);
+		// zlib
+		if (extension_loaded('zlib')){
+			$data = 'on';
+		} else {
+			$data = 'off';
+		}
+		$this->tmpl->addVar("_widget","current_zlib", $data);
 		// gd
 		if (extension_loaded('gd')){
 			$data = 'on';
