@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 575 2008-05-04 06:14:43Z fishbone $
+ * @version    SVN: $Id: admin_mainTemplistWidgetContainer.php 948 2008-08-28 12:26:33Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -174,7 +174,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 				}
 				if ($this->getMsgCount() == 0){		// エラーが発生していないとき
 					// ファイルを保存するサーバディレクトリを指定
-					$tmpFile = tempnam(M3_SYSTEM_WORK_DIR_PATH, M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
+					$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_UPLOAD_FILENAME_HEAD);
 		
 					// アップされたテンポラリファイルを保存ディレクトリにコピー
 					$ret = move_uploaded_file($_FILES['upfile']['tmp_name'], $tmpFile);
@@ -229,7 +229,7 @@ class admin_mainTemplistWidgetContainer extends BaseWidgetContainer
 			$templatesDir = $gEnvManager->getTemplatesPath();		// テンプレートディレクトリ
 			$templateDir = $templatesDir . '/' . $templateId;			// ダウンロードするウィジェットのディレクトリ
 			$downloadFilename = $templateId . '.zip';		// ダウンロード時のファイル名
-			$tmpFile = tempnam(M3_SYSTEM_WORK_DIR_PATH, M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
+			$tmpFile = tempnam($gEnvManager->getWorkDirPath(), M3_SYSTEM_WORK_DOWNLOAD_FILENAME_HEAD);		// zip処理用一時ファイル
 			
 			// zip圧縮
 			$zipFile = new PclZip($tmpFile);
