@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 674 2008-06-02 07:07:51Z fishbone $
+ * @version    SVN: $Id: admin_blog_mainEntryWidgetContainer.php 852 2008-07-23 10:20:20Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_blog_mainBaseWidgetContainer.php');
@@ -227,6 +227,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		if (empty($this->serialNo)) $this->serialNo = 0;
 		$name = $request->trimValueOf('item_name');
 		$html = $request->valueOf('item_html');
+		$html2 = $request->valueOf('item_html2');
 		$status = $request->trimValueOf('item_status');		// エントリー状態(0=未設定、1=編集中、2=公開、3=非公開)
 		$category = '';									// カテゴリー
 		
@@ -274,9 +275,9 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			// エラーなしの場合は、データを登録
 			if ($this->getMsgCount() == 0){
 				if ($act == 'add'){
-					$ret = $this->db->addEntryItem(0, $this->langId, $name, $html, $status, $this->categoryArray, $regUserId, $regDt, $newSerial);
+					$ret = $this->db->addEntryItem(0, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $regUserId, $regDt, $newSerial);
 				} else {
-					$ret = $this->db->addEntryItem($this->entryId, $this->langId, $name, $html, $status, $this->categoryArray, $regUserId, $regDt, $newSerial);
+					$ret = $this->db->addEntryItem($this->entryId, $this->langId, $name, $html, $html2, $status, $this->categoryArray, $regUserId, $regDt, $newSerial);
 				}
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
@@ -293,7 +294,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
-				$ret = $this->db->updateEntryItem($this->serialNo, $name, $html, $status, $this->categoryArray, ''/*投稿者そのまま*/, ''/*投稿日時そのまま*/, $newSerial);
+				$ret = $this->db->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, ''/*投稿者そのまま*/, ''/*投稿日時そのまま*/, $newSerial);
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
 					// シリアル番号更新
@@ -341,6 +342,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				$name = $row['be_name'];				// タイトル
 				$html = $row['be_html'];				// HTML
 				$html = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $html);// アプリケーションルートを変換
+				$html2 = $row['be_html_ext'];				// HTML
+				$html2 = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $gEnvManager->getRootUrl(), $html2);// アプリケーションルートを変換
 				$status = $row['be_status'];				// エントリー状況
 				$reg_user = $row['reg_user_name'];				// 投稿者
 				$reg_dt = $this->convertToDispDateTime($row['be_regist_dt']);				// 投稿日時
@@ -387,6 +390,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "item_name", $name);		// 名前
 		$this->tmpl->addVar("_widget", "item_html", $html);		// HTML
+		$this->tmpl->addVar("_widget", "item_html2", $html2);		// HTML(続き)
 		switch ($status){
 			case 1:	$this->tmpl->addVar("_widget", "selected_edit", 'selected');	break;
 			case 2:	$this->tmpl->addVar("_widget", "selected_public", 'selected');	break;
