@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_contactusWidgetContainer.php 867 2008-07-28 09:04:54Z fishbone $
+ * @version    SVN: $Id: admin_contactusWidgetContainer.php 919 2008-08-21 05:56:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -20,7 +20,8 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
 	const DEFAULT_SEND_MESSAGE = 1;		// メール送信機能を使用するかどうか(デフォルト使用)
-					
+	const DEFAULT_TITLE_NAME = 'お問い合わせ';	// デフォルトのタイトル名
+	
 	/**
 	 * コンストラクタ
 	 */
@@ -66,13 +67,20 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 			$sendMessage = ($request->trimValueOf('send_message') == 'on') ? 1 : 0;		// メール送信機能を使用するかどうか
 			//$emailReceiver = $request->trimValueOf('email_receiver');			// メール受信者
 			$emailReceiver = trim($request->valueOf('email_receiver'));			// メール受信者(aaaa<xxx@xxx.xxx>形式が可能)
+			$showTitle = ($request->trimValueOf('show_title') == 'on') ? 1 : 0;		// タイトルの表示
+			$titleName = trim($request->valueOf('title_name'));				// タイトル名
+			$explanation = trim($request->valueOf('explanation'));				// 説明
 			$companyVisible = ($request->trimValueOf('company_visible') == 'on') ? 1 : 0;		// 会社名入力フィールドの表示
 			$addressVisible = ($request->trimValueOf('address_visible') == 'on') ? 1 : 0;		// 住所入力フィールドの表示
 			$telVisible = ($request->trimValueOf('tel_visible') == 'on') ? 1 : 0;		// 電話番号入力フィールドの表示
+			
 			// 入力値のエラーチェック
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$paramObj->sendMessage = $sendMessage;			// メール送信機能を使用するかどうか
 				$paramObj->emailReceiver = $emailReceiver;		// メール受信者
+				$paramObj->showTitle = $showTitle;				// タイトルの表示
+				$paramObj->titleName = $titleName;				// タイトル名
+				$paramObj->explanation = $explanation;			// 説明
 				$paramObj->companyVisible = $companyVisible;	// 会社名入力フィールドの表示
 				$paramObj->addressVisible = $addressVisible;	// 住所入力フィールドの表示
 				$paramObj->telVisible = $telVisible;	// 電話番号入力フィールドの表示
@@ -88,6 +96,9 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 			// デフォルト値の設定
 			$sendMessage = self::DEFAULT_SEND_MESSAGE;			// メール送信機能を使用するかどうか
 			$emailReceiver = '';		// メール受信者
+			$showTitle = 1;				// タイトルの表示
+			$titleName = self::DEFAULT_TITLE_NAME;			// デフォルトタイトル名
+			$explanation = '';			// 説明
 			$companyVisible = 0;	// 会社名入力フィールドの表示
 			$addressVisible = 0;	// 住所入力フィールドの表示
 			$telVisible = 0;		// 電話番号入力フィールドの表示
@@ -95,6 +106,9 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 			if (!empty($paramObj)){
 				$sendMessage = $paramObj->sendMessage;			// メール送信機能を使用するかどうか
 				$emailReceiver = $paramObj->emailReceiver;		// メール受信者
+				$showTitle = $paramObj->showTitle;				// タイトルの表示
+				$titleName = $paramObj->titleName;				// タイトル名
+				$explanation = $paramObj->explanation;			// 説明
 				$companyVisible = $paramObj->companyVisible;	// 会社名入力フィールドの表示
 				$addressVisible = $paramObj->addressVisible;	// 住所入力フィールドの表示
 				$telVisible = $paramObj->telVisible;		// 電話番号入力フィールドの表示
@@ -105,6 +119,12 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 		if ($sendMessage) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "send_message", $checked);
 		$this->tmpl->addVar("_widget", "email_receiver", $emailReceiver);		// メール受信者
+		$checked = '';
+		if ($showTitle) $checked = 'checked';
+		$this->tmpl->addVar("_widget", "show_title", $checked);
+		$this->tmpl->addVar("_widget", "title_name", $titleName);		// タイトル名
+		$this->tmpl->addVar("_widget", "explanation", $explanation);		// 説明
+		
 		$checked = '';
 		if ($companyVisible) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "company_visible", $checked);// 会社名入力フィールドの表示
@@ -114,6 +134,9 @@ class admin_contactusWidgetContainer extends BaseWidgetContainer
 		$checked = '';
 		if ($telVisible) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "tel_visible", $checked);// 電話番号入力フィールドの表示
+		
+		// パスの設定
+		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 	}
 }
 ?>
