@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contactusWidgetContainer.php 426 2008-03-24 02:50:30Z fishbone $
+ * @version    SVN: $Id: contactusWidgetContainer.php 919 2008-08-21 05:56:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
@@ -24,6 +24,7 @@ class contactusWidgetContainer extends BaseWidgetContainer
 	private $state;		// 都道府県
 	const CONTACTUS_FORM = 'contact_us';		// お問い合わせフォーム
 	const DEFAULT_SEND_MESSAGE = 1;		// メール送信機能を使用するかどうか(デフォルト使用)
+	const DEFAULT_TITLE_NAME = 'お問い合わせ';	// デフォルトのタイトル名
 	
 	/**
 	 * コンストラクタ
@@ -74,6 +75,9 @@ class contactusWidgetContainer extends BaseWidgetContainer
 		// 設定値の取得
 		$sendMessage = self::DEFAULT_SEND_MESSAGE;			// メール送信機能を使用するかどうか
 		$emailReceiver = '';		// メール受信者
+		$showTitle = 1;				// タイトルを表示するかどうか
+		$titleName = self::DEFAULT_TITLE_NAME;			// タイトル名
+		$explanation = '';			// 説明
 		$companyVisible = 0;	// 会社名入力フィールドの表示
 		$addressVisible = 0;	// 住所入力フィールドの表示
 		$telVisible = 0;		// 電話番号入力フィールドの表示
@@ -81,6 +85,9 @@ class contactusWidgetContainer extends BaseWidgetContainer
 		if (!empty($paramObj)){
 			$sendMessage = $paramObj->sendMessage;			// メール送信機能を使用するかどうか
 			$emailReceiver = $paramObj->emailReceiver;		// メール受信者
+			$showTitle = $paramObj->showTitle;				// タイトルを表示するかどうか
+			if (!empty($paramObj->titleName)) $titleName = $paramObj->titleName;			// タイトル名
+			$explanation = $paramObj->explanation;			// 説明
 			$companyVisible = $paramObj->companyVisible;	// 会社名入力フィールドの表示
 			$addressVisible = $paramObj->addressVisible;	// 住所入力フィールドの表示
 			$telVisible = $paramObj->telVisible;		// 電話番号入力フィールドの表示
@@ -192,6 +199,16 @@ class contactusWidgetContainer extends BaseWidgetContainer
 				$this->tmpl->addVar("_widget", "send_button_disabled", 'disabled');// 送信ボタン
 			}
 		}
+		// タイトルの表示
+		if ($showTitle){
+			$this->tmpl->setAttribute('show_title', 'visibility', 'visible');
+			$this->tmpl->addVar("show_title", "title_name", $titleName);// タイトル名
+		}
+		// 説明の表示
+		if (!empty($explanation)){
+			$this->tmpl->setAttribute('show_explanation', 'visibility', 'visible');
+			$this->tmpl->addVar("show_explanation", "explanation", $explanation);// 説明
+		}
 		// 入力フィールドの表示制御
 		if ($companyVisible) $this->tmpl->setAttribute('show_company_name', 'visibility', 'visible');// 会社名入力フィールドの表示
 		if ($addressVisible){	// 住所入力フィールドの表示
