@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: contentDb.php 477 2008-04-07 03:55:26Z fishbone $
+ * @version    SVN: $Id: contentDb.php 791 2008-06-25 03:30:58Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -172,38 +172,43 @@ class contentDb extends BaseDb
 	/**
 	 * コンテンツ項目の削除
 	 *
-	 * @param string  $contentType	コンテンツタイプ
-	 * @param string  $contentId	コンテンツID(0のとき新規)
-	 * @param string  $lang			言語ID
+	 * @param array $serial			シリアルNo
 	 * @param int $userId			ユーザID(データ更新者)
 	 * @return						true=成功、false=失敗
 	 */
-	function delContentItem($contentType, $contentId, $lang, $userId)
+	function delContentItem($serial, $userId)
 	{
 		$now = date("Y/m/d H:i:s");	// 現在日時
 		
-		// 前レコードの削除状態チェック
-		$queryStr = 'SELECT * FROM content ';
-		$queryStr .=  'WHERE cn_type = ? ';
-		$queryStr .=    'AND cn_id = ? ';
-		$queryStr .=    'AND cn_language_id = ? ';
-		$queryStr .=  'ORDER BY cn_history_index DESC ';
-		$ret = $this->selectRecord($queryStr, array($contentType, $contentId, $lang), $row);
-		if ($ret){
-			if ($row['cn_deleted']){		// レコードが削除されていれば終了
+		// 引数エラーチェック
+		if (!is_array($serial) || count($serial) <= 0) return true;
+
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		for ($i = 0; $i < count($serial); $i++){
+			$queryStr  = 'SELECT * FROM content ';
+			$queryStr .=   'WHERE cn_deleted = false ';		// 未削除
+			$queryStr .=     'AND cn_serial = ? ';
+			$ret = $this->isRecordExists($queryStr, array($serial[$i]));
+			// 存在しない場合は、既に削除されたとして終了
+			if (!$ret){
+				$this->endTransaction();
 				return false;
 			}
-		} else {
-			return false;
 		}
-			
-		// 古いレコードを削除
+		
+		// レコードを削除
 		$queryStr  = 'UPDATE content ';
 		$queryStr .=   'SET cn_deleted = true, ';	// 削除
 		$queryStr .=     'cn_update_user_id = ?, ';
 		$queryStr .=     'cn_update_dt = ? ';
-		$queryStr .=   'WHERE cn_serial = ?';
-		$ret = $this->execStatement($queryStr, array($userId, $now, $row['cn_serial']));
+		$queryStr .=   'WHERE cn_serial in (' . implode($serial, ',') . ') ';
+		$this->execStatement($queryStr, array($userId, $now));
+
+		// トランザクション確定
+		$ret = $this->endTransaction();
 		return $ret;
 	}
 	/**
@@ -220,6 +225,23 @@ class contentDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($serial), $row);
 		return $ret;
 	}
+	/**
+	 * デフォルトのコンテンツ項目総数取得
+	 *
+	 * @param string	$contentType		コンテンツタイプ
+	 * @param string	$lang				言語
+	 * @return int					総数
+	 */
+	function getDefaultContentCount($contentType, $lang)
+	{
+		$queryStr = 'SELECT * FROM content ';
+		$queryStr .=  'WHERE cn_visible = true ';
+		$queryStr .=    'AND cn_default = true ';
+		$queryStr .=    'AND cn_deleted = false ';		// 削除されていない
+		$queryStr .=    'AND cn_type = ? ';
+		$queryStr .=    'AND cn_language_id = ? ';
+		return $this->selectRecordCount($queryStr, array($contentType, $lang));
+	}
 	/**
 	 * メニュー項目の追加
 	 *
