@@ -10,13 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_sample_inputWidgetContainer.php 413 2008-03-19 06:05:13Z fishbone $
+ * @version    SVN: $Id: m_sample_inputWidgetContainer.php 774 2008-06-21 05:30:23Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
-require_once($gEnvManager->getCommonPath()			. '/htmlEdit.php');
+require_once($gEnvManager->getContainerPath()		. '/baseMobileWidgetContainer.php');
 
-class m_sample_inputWidgetContainer extends BaseWidgetContainer
+class m_sample_inputWidgetContainer extends BaseMobileWidgetContainer
 {
 	/**
 	 * コンストラクタ
@@ -63,6 +62,10 @@ class m_sample_inputWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "msg", $msg);
 		$this->tmpl->addVar("_widget", "link", $gEnvManager->createCurrentPageUrlWithSessionId());
 		$this->tmpl->addVar("_widget", "url", $gEnvManager->createCurrentPageUrlWithSessionId());
+		
+		// 携帯キャリア、機種
+		$this->tmpl->addVar("_widget", "carrier", $this->agent->getCarrierLongName());
+		$this->tmpl->addVar("_widget", "type", $this->agent->getModel());
 	}
 }
 ?>
