@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_photoslideWidgetContainer.php 937 2008-08-24 11:16:20Z fishbone $
+ * @version    SVN: $Id: admin_photoslideWidgetContainer.php 962 2008-08-31 03:57:04Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -29,6 +29,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 	private $speedItems = array('slow', 'normal', 'fast');
 	private $effect;		// 選択中のエフェクト
 	private $speed;			// エフェクトのspeedパラメータ
+	private $css;			// 追加CSS
 	const DEFAULT_NAME_HEAD = '名称未設定';			// デフォルトの設定名
 	const DEFAULT_DIR = '/resource/image/sample/photo';			// デフォルト読み込みディレクトリ
 	const DEFAULT_CSS = ".photoslide {\n    height:  160px;\n    width:   180px;\n    padding: 0;\n    margin:  0;\n}\n.photoslide img {\n    padding: 10px;\n    border:  1px solid #ccc;\n    background-color: #eee;\n    width:  150px;\n    height: 113px;\n    top:  0;\n    left: 0;\n}";
@@ -110,7 +111,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 
 		$name	= $request->trimValueOf('item_name');			// ヘッダタイトル
 		$url	= $request->trimValueOf('item_url');		// 画像読み込みURL
-		$css	= $request->trimValueOf('item_css');		// 追加CSS
+		$this->css	= $request->trimValueOf('item_css');		// 追加CSS
 		$showTitle = ($request->trimValueOf('item_showtitle') == 'on') ? 1 : 0;		// タイトルを表示するかどうか
 		$this->effect	= $request->trimValueOf('item_effect');		// エフェクト
 		$this->speed	= $request->trimValueOf('item_speed');
@@ -146,7 +147,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 				$newObj = new stdClass;
 				$newObj->name	= $name;// 表示名
 				$newObj->url = $url;		// 画像読み込みURL
-				$newObj->css = $css;		// 追加CSS
+				$newObj->css = $this->css;		// 追加CSS
 				$newObj->showTitle	= $showTitle;					// タイトルを表示するかどうか
 				$newObj->effect		= $this->effect;				// エフェクト
 				$newObj->speed		= $this->speed;
@@ -174,7 +175,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		} else if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
@@ -190,7 +191,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 					if ($id == $this->configId){
 						// ウィジェットオブジェクト更新
 						$targetObj->url	= $url;		// 画像読み込みURL
-						$targetObj->css = $css;		// 追加CSS
+						$targetObj->css = $this->css;		// 追加CSS
 						$targetObj->showTitle	= $showTitle;					// タイトルを表示するかどうか
 						$targetObj->effect		= $this->effect;				// エフェクト
 						$targetObj->speed		= $this->speed;
@@ -210,13 +211,12 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 					
 					if (empty($defConfigId)){		// 画面定義の定義IDが設定されていないときは設定
 						$defConfigId = $this->configId;		// 定義定義IDを更新
-						$gPageManager->updateParentWindow();// 親ウィンドウを更新
 					}
 					$replaceNew = true;			// データ再取得
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		} else if ($act == 'select'){	// 定義IDを変更
 			$replaceNew = true;			// データ再取得
@@ -230,7 +230,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 			$this->tmpl->setAttribute('item_name_visible', 'visibility', 'visible');// 名前入力フィールド表示
 			$name = $this->createDefaultName();			// デフォルト登録項目名
 			$url = M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END . self::DEFAULT_DIR;		// FlashファイルのURL
-			$css = self::DEFAULT_CSS;		// 追加CSS
+			$this->css = self::DEFAULT_CSS;		// 追加CSS
 			$showTitle = 1;					// タイトルを表示するかどうか
 			$this->effect	= self::DEFAULT_EFFECT;				// エフェクト
 			$this->speed	= '';
@@ -247,7 +247,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 				if ($replaceNew){		// データ再取得のとき
 					$name	= $targetObj->name;// 名前
 					$url	= $targetObj->url;		// 画像読み込みURL
-					$css	= $targetObj->css;		// 追加CSS
+					$this->css	= $targetObj->css;		// 追加CSS
 					$showTitle		= $targetObj->showTitle;		// タイトルを表示するかどうか
 					$this->effect	= $targetObj->effect;			// エフェクト
 					$this->speed	= $targetObj->speed;
@@ -271,7 +271,7 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("item_name_visible", "name", $name);		// 名前
 		$this->tmpl->addVar("_widget", "url",	$url);
-		$this->tmpl->addVar("_widget", "css",	$css);
+		$this->tmpl->addVar("_widget", "css",	$this->css);
 		$this->tmpl->addVar("_widget", "preview_url",	$previewUrl);
 		
 		$checked = '';
@@ -292,8 +292,20 @@ class admin_photoslideWidgetContainer extends BaseWidgetContainer
 		} else {
 			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 「更新」ボタン
 		}
-		// ヘッダにCSSを追加
-		$gPageManager->addHeadCss($css);
+	}
+	/**
+	 * CSSデータをHTMLヘッダ部に設定
+	 *
+	 * CSSデータをHTMLのheadタグ内に追加出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。
+	 * @return string 						CSS文字列。出力しない場合は空文字列を設定。
+	 */
+	function _addCssData($request, &$param)
+	{
+		return $this->css;
 	}
 	/**
 	 * 選択用メニューを作成
