@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: default.ini.php 1064 2008-10-09 07:15:22Z fishbone $
+// $Id: default.ini.php 1111 2008-10-24 01:25:15Z fishbone $
 // Copyright (C)
 //   2003-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -93,7 +93,8 @@ $rule_related_str = "</li>\n<li>";
 
 /////////////////////////////////////////////////
 // 水平線のタグ
-$hr = '<hr class="full_hr" />';
+//$hr = '<hr class="full_hr" />';
+$hr = '<hr class="wiki_hr" />';
 
 /////////////////////////////////////////////////
 // 脚注機能関連
