@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone
-// $Id: pukiwiki.ini.php 1084 2008-10-18 06:10:55Z fishbone $
+// $Id: pukiwiki.ini.php 1117 2008-10-24 11:41:04Z fishbone $
 // Copyright (C)
 //   2002-2006 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -15,6 +15,7 @@ global $modifierlink;
 global $whatsnew;
 global $whatsdeleted;
 global $interwiki;
+global $menubar;
 
 global $nofollow;
 global $trackback;
@@ -141,12 +142,13 @@ define('DATA_DIR',      DATA_HOME . 'wiki/'     ); // Latest wiki texts
 define('DIFF_DIR',      DATA_HOME . 'diff/'     ); // Latest diffs
 define('BACKUP_DIR',    DATA_HOME . 'backup/'   ); // Backups
 define('CACHE_DIR',     DATA_HOME . 'cache/'    ); // Some sort of caches
-define('UPLOAD_DIR',    DATA_HOME . 'attach/'   ); // Attached files and logs
+//define('UPLOAD_DIR',    DATA_HOME . 'attach/'   ); // Attached files and logs
+define('UPLOAD_DIR',    $gEnvManager->getCurrentWidgetRootPath() . '/upload/'); // Attached files and logs
 define('COUNTER_DIR',   DATA_HOME . 'counter/'  ); // Counter plugin's counts
 define('TRACKBACK_DIR', DATA_HOME . 'trackback/'); // TrackBack logs
 // modified for Magic3 by naoki on 2008/9/26
 //define('PLUGIN_DIR',    DATA_HOME . 'plugin/'   ); // Plugin directory
-define('PLUGIN_DIR',    $gEnvManager->getCurrentWidgetIncludePath() . '/plugin/'   ); // Plugin directory
+define('PLUGIN_DIR',    $gEnvManager->getCurrentWidgetIncludePath() . '/plugin/'); // Plugin directory
 
 /////////////////////////////////////////////////
 // Directory settings II (ended with '/')
