@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_wiki_mainWidgetContainer.php 1075 2008-10-14 05:38:05Z fishbone $
+ * @version    SVN: $Id: admin_wiki_mainWidgetContainer.php 1077 2008-10-14 09:59:50Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -23,9 +23,11 @@ class admin_wiki_mainWidgetContainer extends BaseWidgetContainer
 	private $authType;		// 認証方法
 	const DEFAULT_PASSWORD = '********';	// 設定済みを示すパスワード
 	const DEFAULT_AUTH_TYPE = 'admin';		// デフォルトの認証タイプ
+	const DEFAULT_PAGE = 'FrontPage';		// デフォルトのページ
 	const CONFIG_KEY_AUTH_TYPE = 'auth_type';			// 認証タイプ(admin=管理権限ユーザ、loginuser=ログインユーザ、password=共通パスワード)
 	const CONFIG_KEY_SHOW_PAGE_TITLE = 'show_page_title';
 	const CONFIG_KEY_PASSWORD = 'password';		// 共通パスワード
+	const CONFIG_KEY_DEFAULT_PAGE = 'default_page';		// デフォルトページ
 	
 	/**
 	 * コンストラクタ
@@ -104,18 +106,20 @@ class admin_wiki_mainWidgetContainer extends BaseWidgetContainer
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				$ret = true;		// エラー値リセット
-				
-				// パスワードが設定されているときは更新
-				if (!empty($password)){
-					$ret = $this->db->updateConfig(self::CONFIG_KEY_PASSWORD, $password);
-				}
 				// 認証タイプ
-				if ($ret){
-					$ret = $this->db->updateConfig(self::CONFIG_KEY_AUTH_TYPE, $this->authType);
-				}
+				if ($ret) $ret = $this->db->updateConfig(self::CONFIG_KEY_AUTH_TYPE, $this->authType);
+	
+				// パスワードが設定されているときは更新
+				if (!empty($password)) $ret = $this->db->updateConfig(self::CONFIG_KEY_PASSWORD, $password);
+
+				// デフォルトページ
+				if ($ret) $ret = $this->db->updateConfig(self::CONFIG_KEY_DEFAULT_PAGE, $defaultPage);
+				
+				// タイトルの表示状態
+				if ($ret) $ret = $this->db->updateConfig(self::CONFIG_KEY_SHOW_PAGE_TITLE, $showTitle);
+								
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
-					
 					$replaceNew = true;			// データ再取得
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
@@ -130,6 +134,18 @@ class admin_wiki_mainWidgetContainer extends BaseWidgetContainer
 			} else {
 				$this->authType = $value;
 			}
+			$value = $this->db->getConfig(self::CONFIG_KEY_DEFAULT_PAGE);// デフォルトページ
+			if (empty($value)){
+				$defaultPage = self::DEFAULT_PAGE;
+			} else {
+				$defaultPage = $value;
+			}
+			$value = $this->db->getConfig(self::CONFIG_KEY_SHOW_PAGE_TITLE);// タイトル表示状態
+			if ($value == ''){
+				$showTitle = '1';		// 表示
+			} else {
+				$showTitle = $value;
+			}
 		}
 		
 		// 認証方法メニュー作成
@@ -139,27 +155,11 @@ class admin_wiki_mainWidgetContainer extends BaseWidgetContainer
 		if ($this->authType != 'password') $this->tmpl->addVar("_widget", "pwd_style", 'style="display:none;"');
 		
 		// 画面にデータを埋め込む
-		$this->tmpl->addVar("item_name_visible", "name", $name);		// 名前
-		$this->tmpl->addVar("_widget", "width",	$width);
-		$this->tmpl->addVar("_widget", "height",	$height);
-		$this->tmpl->addVar("_widget", "movie_id",	$movieId);
+		$this->tmpl->addVar("_widget", "default_page", $defaultPage);		// デフォルトページ
 		$checked = '';
 		if ($showTitle) $checked = 'checked';
 		$this->tmpl->addVar("_widget", "show_title", $checked);	// タイトルを表示するかどうか
 		$this->tmpl->addVar("_widget", "pwd", self::DEFAULT_PASSWORD);// 入力済みを示すパスワードの設定
-
-		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
-		
-
-		
-		// ボタンの表示制御
-	/*	if (empty($this->serialNo)){		// 新規追加項目を選択しているとき
-			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');// 「新規追加」ボタン
-		} else {
-			$this->tmpl->setAttribute('update_button', 'visibility', 'visible');// 「更新」ボタン
-			//$this->tmpl->setAttribute('del_button', 'visibility', 'visible');// 「削除」ボタン
-		}*/
 	}
 	/**
 	 * 認証方法メニューを作成
