@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wiki_mainDb.php 1081 2008-10-16 05:08:59Z fishbone $
+ * @version    SVN: $Id: wiki_mainDb.php 1124 2008-10-25 04:09:51Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -49,6 +49,54 @@ class wiki_mainDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
 		return $ret;
 	}
+	/**
+	 * Wikiページデータを履歴番号で取得
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param int $history			履歴番号
+	 * @param array   $row			レコード
+	 * @param string  $type			ページタイプ
+	 * @return bool					取得 = true, 取得なし= false
+	 */
+	function getPageWithHistory($name, $history, &$row, $type='')
+	{
+		$queryStr  = 'SELECT * FROM wiki_content ';
+		$queryStr .=   'WHERE wc_type = ? ';
+		$queryStr .=   'AND wc_id = ? ';
+		$queryStr .=   'AND wc_history_index = ? ';
+		$ret = $this->selectRecord($queryStr, array($type, $name, $history), $row);
+		return $ret;
+	}
+	/**
+	 * 履歴情報を取得
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param int $history			履歴番号(-1のときはすべてのレコードを取得)
+	 * @param array   $row			レコード
+	 * @param string  $type			ページタイプ
+	 * @return bool					取得 = true, 取得なし= false
+	 */
+	function getPageInfo($name, $history, &$rows, $type='')
+	{
+		$param = array($name, $type);
+		$queryStr .= 'SELECT wc_serial, ';
+		$queryStr .=   'wc_id, ';
+		$queryStr .=   'wc_history_index, ';
+		$queryStr .=   'wc_content_dt, ';
+		$queryStr .=   'wc_update_user_id, ';
+		$queryStr .=   'wc_update_dt, ';
+		$queryStr .=   'wc_deleted ';
+		$queryStr .= 'FROM wiki_content ';
+		$queryStr .= 'WHERE wc_id = ? ';	
+		$queryStr .=   'AND wc_type = ? ';
+		if ($history != -1){
+			$queryStr .=   'AND wc_history_index = ? ';
+			$param[] = $history;
+		}
+		$queryStr .= 'ORDER BY wc_history_index';
+		$ret = $this->selectRecords($queryStr, $param, $rows);
+		return $ret;
+	}
 	/**
 	 * 取得可能なWikiページ名の取得
 	 *
@@ -70,6 +118,26 @@ class wiki_mainDb extends BaseDb
 		}
 		return $retValue;
 	}
+	/**
+	 * すべてのWikiページ名の取得
+	 *
+	 * @param string  $type			ページタイプ
+	 * @return array				ページ名
+	 */
+	function getAllPages($type='')
+	{
+		$retValue = array();
+		$queryStr  = 'SELECT DISTINCT wc_id FROM wiki_content ';
+		$queryStr .=   'WHERE wc_type = ? ';
+		$queryStr .=    'ORDER BY wc_id';
+		$ret = $this->selectRecords($queryStr, array($type), $rows);
+		if ($ret){
+			for ($i = 0; $i < count($rows); $i++){
+				$retValue[] = $rows[$i]['wc_id'];
+			}
+		}
+		return $retValue;
+	}
 	/**
 	 * Wikiページの更新
 	 *
@@ -126,6 +194,46 @@ class wiki_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * Wikiページを削除
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param string  $type			ページタイプ
+	 * @return bool					true=成功、false=失敗
+	 */
+	function deletePage($name, $type='')
+	{
+		global $gEnvManager;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクションスタート
+		$this->startTransaction();
+				
+		// レコードを取得
+		$queryStr = 'SELECT * from wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_deleted = false';
+		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
+		if (!$ret){
+			// トランザクション終了
+			$ret = $this->endTransaction();
+			return false;
+		}
+		
+		$queryStr  = 'UPDATE wiki_content ';
+		$queryStr .=   'SET wc_deleted = true, ';	// 削除
+		$queryStr .=     'wc_update_user_id = ?, ';
+		$queryStr .=     'wc_update_dt = ? ';
+		$queryStr .=   'WHERE wc_serial = ?';
+		$this->execStatement($queryStr, array($userId, $now, $row['wc_serial']));
+		
+		// トランザクション終了
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * Wikiページのロックの制御
 	 *
@@ -171,6 +279,49 @@ class wiki_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * Wikiページの更新日付を更新
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param timestamp $time		更新日時(nullのときは、現在日時を設定)
+	 * @param string  $type			ページタイプ
+	 * @return bool					true=成功、false=失敗
+	 */
+	function updatePageTime($name, $time, $type='')
+	{
+		global $gEnvManager;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $gEnvManager->getCurrentUserId();	// 現在のユーザ
+		
+		// トランザクションスタート
+		$this->startTransaction();
+				
+		// レコードを取得
+		$queryStr = 'SELECT * from wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_deleted = false';
+		$ret = $this->selectRecord($queryStr, array($type, $name), $row);
+		if (!$ret){
+			// トランザクション終了
+			$ret = $this->endTransaction();
+			return false;
+		}
+		
+		// コンテンツ更新日時
+		$contentTime = $time;
+		if ($contentTime == null) $contentTime = $now;
+
+		$queryStr  = 'UPDATE wiki_content ';
+		$queryStr .=   'SET wc_content_dt = ? ';	// コンテンツ更新日時
+		$queryStr .=   'WHERE wc_serial = ?';
+		$this->execStatement($queryStr, array($contentTime, $row['wc_serial']));
+		
+		// トランザクション終了
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * Wikiページその他データの更新
 	 *
@@ -237,6 +388,21 @@ class wiki_mainDb extends BaseDb
 			return '';
 		}
 	}
+	/**
+	 * Wikiページその他データが存在するかチェック
+	 *
+	 * @param string  $name			ウィキページ名
+	 * @param string  $type			ページタイプ
+	 * @return				true=存在する、false=存在しない
+	 */
+	function isExistsPageOther($name, $type)
+	{
+		$queryStr = 'SELECT * FROM wiki_content ';
+		$queryStr .=  'WHERE wc_type = ? ';
+		$queryStr .=    'AND wc_id = ? ';
+		$queryStr .=    'AND wc_history_index = 0';
+		return $this->isRecordExists($queryStr, array($type, $name));
+	}
 	/**
 	 * Wikiページその他データを削除
 	 *
