@@ -1,6 +1,6 @@
 <?php
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: ja.lng.php 1049 2008-09-29 09:28:58Z fishbone $
+// $Id: ja.lng.php 1091 2008-10-20 07:49:54Z fishbone $
 // Copyright (C)
 //   2002-2005 PukiWiki Developers Team
 //   2001-2002 Originally written by yu-ji
@@ -502,7 +502,8 @@ $_rename_messages  = array(
 	'err_notpage'    => '%sはページ名ではありません。',
 	'err_norename'   => '%sをリネームすることはできません。',
 	'err_already'    => 'ページがすでに存在します。:%s',
-	'err_already_below' => '以下のファイルがすでに存在します。',
+	//'err_already_below' => '以下のファイルがすでに存在します。',
+	'err_already_below' => '以下のページがすでに存在します。',
 	'msg_title'      => 'ページ名の変更',
 	'msg_page'       => '変更元ページを指定',
 	'msg_regex'      => '正規表現で置換',
@@ -514,9 +515,12 @@ $_rename_messages  = array(
 	'msg_adminpass'  => '管理者パスワード',
 	'msg_arrow'      => '→',
 	'msg_exist_none' => 'そのページを処理しない',
-	'msg_exist_overwrite' => 'そのファイルを上書きする',
-	'msg_confirm'    => '以下のファイルをリネームします。',
-	'msg_result'     => '以下のファイルを上書きしました。',
+	//'msg_exist_overwrite' => 'そのファイルを上書きする',
+	'msg_exist_overwrite' => 'そのページを上書きする',
+	//'msg_confirm'    => '以下のファイルをリネームします。',
+	'msg_confirm'    => '以下のページをリネームします。',
+	//'msg_result'     => '以下のファイルを上書きしました。',
+	'msg_result'     => '以下のページを上書きしました。',
 	'btn_submit'     => '実行',
 	'btn_next'       => '次へ'
 );
