@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: func.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: func.php 1086 2008-10-18 10:07:39Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -147,7 +147,8 @@ function auto_template($page)
 		$template_page = preg_replace($rule_pattrn, $template, $page);
 		if (! is_page($template_page)) continue;
 
-		$body = join('', get_source($template_page));
+		//$body = join('', get_source($template_page));
+		$body = get_source($template_page, true);
 
 		// Remove fixed-heading anchors
 		$body = preg_replace('/^(\*{1,3}.*)\[#[A-Za-z][\w-]+\](.*)$/m', '$1$2', $body);
@@ -281,7 +282,7 @@ function do_search($word, $type = 'AND', $non_format = FALSE, $base = '')
 		foreach ($keys as $key) {
 			// modified for Magic3 by naoki on 2008/9/28
 			//$b_match = preg_match($key, get_source($page, TRUE, TRUE));
-			$b_match = preg_match($key, join('', get_source($page)));
+			$b_match = preg_match($key, get_source($page, true));
 			if ($b_type xor $b_match) break; // OR
 		}
 		if ($b_match) continue;
