@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: html.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: html.php 1108 2008-10-23 11:46:32Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -61,7 +61,8 @@ function edit_form($page, $postdata, $digest = FALSE, $b_template = TRUE)
 	global $notimeupdate;
 
 	// Newly generate $digest or not
-	if ($digest === FALSE) $digest = md5(join('', get_source($page)));
+	//if ($digest === FALSE) $digest = md5(join('', get_source($page)));
+	if ($digest === FALSE) $digest = md5(get_source($page, true));
 
 	$refer = $template = '';
  
