@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: link.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: link.php 1108 2008-10-23 11:46:32Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C) 2003-2006 PukiWiki Developers Team
@@ -152,7 +152,7 @@ function links_update($page)
 // Init link cache (Called from link plugin)
 function links_init()
 {
-	global $whatsnew;
+//	global $whatsnew;
 
 	if (PKWK_READONLY) return; // Do nothing
 
@@ -169,7 +169,9 @@ function links_init()
 
 	$ref   = array(); // 参照元
 	foreach (get_existpages() as $page) {
-		if ($page == $whatsnew) continue;
+		//if ($page == $whatsnew) continue;
+		// キャッシュを作成しないページはとばす
+		if ($page == WikiConfig::getWhatsnewPage()) continue;
 
 		$rel   = array(); // 参照先
 		$links = links_get_objects($page);
@@ -288,7 +290,7 @@ function links_get_objects($page, $refresh = FALSE)
 	static $obj;
 
 	if (! isset($obj) || $refresh)
-		$obj = & new InlineConverter(NULL, array('note'));
+		$obj = new InlineConverter(NULL, array('note'));
 
 	$result = $obj->get_objects(join('', preg_grep('/^(?!\/\/|\s)./', get_source($page))), $page);
 	return $result;
