@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: attach.inc.php 1083 2008-10-17 15:35:10Z fishbone $
+ * @version    SVN: $Id: attach.inc.php 1095 2008-10-21 08:51:41Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -212,8 +212,9 @@ function attach_upload($file, $page, $pass = NULL)
 	if (move_uploaded_file($file['tmp_name'], $obj->filename))
 		chmod($obj->filename, PLUGIN_ATTACH_FILE_MODE);
 
-	if (is_page($page))
-		touch(get_filename($page));
+	//if (is_page($page)) touch(get_filename($page));
+	// ページの更新日時を更新
+	if (is_page($page)) WikiPage::updatePageTime($page);
 
 	$obj->getstatus();
 	$obj->status['pass'] = ($pass !== TRUE && $pass !== NULL) ? md5($pass) : '';
@@ -221,18 +222,21 @@ function attach_upload($file, $page, $pass = NULL)
 
 	if ($notify) {
 		$footer['ACTION']   = 'File attached';
-		$footer['FILENAME'] = & $file['name'];
-		$footer['FILESIZE'] = & $file['size'];
-		$footer['PAGE']     = & $page;
+		$footer['FILENAME'] = $file['name'];
+		$footer['FILESIZE'] = $file['size'];
+		$footer['PAGE']     = $page;
 
 		$footer['URI']      = get_script_uri() .
 			//'?' . rawurlencode($page);
-
 			// MD5 may heavy
-			'?plugin=attach' .
+			/*'?plugin=attach' .
 				'&refer=' . rawurlencode($page) .
 				'&file='  . rawurlencode($file['name']) .
-				'&pcmd=info';
+				'&pcmd=info';*/
+			WikiParam::convQuery('?plugin=attach' .
+				'&refer=' . rawurlencode($page) .
+				'&file='  . rawurlencode($file['name']) .
+				'&pcmd=info', false);
 
 		$footer['USER_AGENT']  = TRUE;
 		$footer['REMOTE_ADDR'] = TRUE;
@@ -441,12 +445,21 @@ function attach_form($page)
 
 	$r_page = rawurlencode($page);
 	$s_page = htmlspecialchars($page);
+	$linkList		= $script. WikiParam::convQuery("?plugin=attach&amp;pcmd=list&amp;refer=$r_page");
+	$linkListAll	= $script. WikiParam::convQuery("?plugin=attach&amp;pcmd=list");
+	$navi = <<<EOD
+  <span class="small">
+   [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
+   [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
+  </span><br />
+EOD;
+/*
 	$navi = <<<EOD
   <span class="small">
    [<a href="$script?plugin=attach&amp;pcmd=list&amp;refer=$r_page">{$_attach_messages['msg_list']}</a>]
    [<a href="$script?plugin=attach&amp;pcmd=list">{$_attach_messages['msg_listall']}</a>]
   </span><br />
-EOD;
+EOD;*/
 
 	if (! ini_get('file_uploads')) return '#attach(): file_uploads disabled<br />' . $navi;
 	if (! is_page($page))          return '#attach(): No such page<br />'          . $navi;
@@ -455,9 +468,11 @@ EOD;
 	$msg_maxsize = sprintf($_attach_messages['msg_maxsize'], number_format($maxsize/1024) . 'KB');
 
 	$pass = '';
+	$hiddenPath = '';
 	if (PLUGIN_ATTACH_PASSWORD_REQUIRE || PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY) {
 		$title = $_attach_messages[PLUGIN_ATTACH_UPLOAD_ADMIN_ONLY ? 'msg_adminpass' : 'msg_password'];
-		$pass = '<br />' . $title . ': <input type="password" name="pass" size="8" />';
+		$pass = '<br />' . $title . ': <input type="password" name="password" size="8" />';
+		$hiddenPath = '<input type="hidden" name="pass" />';
 	}
 	$postScript = $script . WikiParam::convQuery("?");
 	$retValue = <<<EOD
@@ -467,13 +482,14 @@ EOD;
   <input type="hidden" name="pcmd"   value="post" />
   <input type="hidden" name="refer"  value="$s_page" />
   <input type="hidden" name="max_file_size" value="$maxsize" />
+  $hiddenPath
   $navi
   <span class="small">
    $msg_maxsize
   </span><br />
   <label for="_p_attach_file">{$_attach_messages['msg_file']}:</label> <input type="file" name="attach_file" id="_p_attach_file" />
   $pass
-  <input type="submit" value="{$_attach_messages['btn_upload']}" />
+  <input type="submit" value="{$_attach_messages['btn_upload']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
  </div>
 </form>
 EOD;
@@ -528,13 +544,32 @@ class AttachFile
 		if (! $this->exist) return FALSE;
 
 		// ログファイル取得
-		if (file_exists($this->logname)) {
+		/*if (file_exists($this->logname)) {
 			$data = file($this->logname);
 			foreach ($this->status as $key=>$value) {
 				$this->status[$key] = chop(array_shift($data));
 			}
 			$this->status['count'] = explode(',', $this->status['count']);
+		}*/
+		// 1レコード(行)のパターンは、「ファイル名」「元のファイル名」「世代番号」「アクセスカウント数」「ハッシュ値」「凍結状態」をタブ区切りで格納
+		$keyFilename = basename($this->filename);
+		$lines = WikiPage::getPageUpload($this->page);
+		foreach ($lines as $line){
+			$lineData = rtrim($line);
+			if (empty($lineData)) continue;
+			
+			list($filename, $originalFilename, $age, $count, $hash, $freeze) = explode("\t", $lineData);
+			if ($filename == $keyFilename){
+				$this->status['age'] = $age;
+				$this->status['count'] = $count;
+				$this->status['pass'] = $hash;
+				$this->status['freeze'] = $freeze;
+				
+				$this->status['count'] = explode(',', $this->status['count']);		// 複数設定のときは配列にする
+				break;
+			}
 		}
+		
 		$this->time_str = get_date('Y/m/d H:i:s', $this->time);
 		$this->size     = filesize($this->filename);
 		$this->size_str = sprintf('%01.1f', round($this->size/1024, 1)) . 'KB';
@@ -546,6 +581,7 @@ class AttachFile
 	// ステータス保存
 	function putstatus()
 	{
+	/*
 		$this->status['count'] = join(',', $this->status['count']);
 		$fp = fopen($this->logname, 'wb') or
 			die_message('cannot write ' . $this->logname);
@@ -556,7 +592,34 @@ class AttachFile
 			fwrite($fp, $value . "\n");
 		}
 		flock($fp, LOCK_UN);
-		fclose($fp);
+		fclose($fp);*/
+		
+		// 配列を文字列に変換
+		$this->status['count'] = join(',', $this->status['count']);
+		
+		// 1レコード(行)のパターンは、「ファイル名」「世代番号」「アクセスカウント数」「ハッシュ値」「凍結状態」をタブ区切りで格納
+		$keyFilename = basename($this->filename);
+		$lines = WikiPage::getPageUpload($this->page);
+		for ($i = 0; $i < count($lines); $i++){
+			$lineData = rtrim($lines[$i]);
+			if (empty($lineData)) continue;
+			
+			list($filename, $originalFilename, $age, $count, $hash, $freeze) = explode("\t", $lineData);
+			if ($filename == $keyFilename){
+				array_splice($lines, $i, 1);
+				break;
+			}
+		}
+		// 新規データ追加
+		$newLine = '';
+		$newLine .= $keyFilename . "\t";
+		$newLine .= $this->file . "\t";		// 元のファイル名
+		$newLine .= $this->status['age'] . "\t";
+		$newLine .= $this->status['count'] . "\t";
+		$newLine .= $this->status['pass'] . "\t";
+		$newLine .= $this->status['freeze'] . "\n";
+		$lines[] = $newLine;
+		WikiPage::updatePageUpload($this->page, join('', $lines));
 	}
 
 	// 日付の比較関数
@@ -577,13 +640,22 @@ class AttachFile
 			$label .= ' (backup No.' . $this->age . ')';
 		}
 		$info = $count = '';
+		$infoUrl = $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=info$param");
+		$openUrl = $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=open$param");
 		if ($showinfo) {
+			$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
+			$info = "\n<span class=\"small\">[<a href=\"$infoUrl\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]</span>\n";
+			$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
+				sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
+		}
+		return "<a href=\"$openUrl\" title=\"$title\">$label</a>$count$info";
+		/*if ($showinfo) {
 			$_title = str_replace('$1', rawurlencode($this->file), $_attach_messages['msg_info']);
 			$info = "\n<span class=\"small\">[<a href=\"$script?plugin=attach&amp;pcmd=info$param\" title=\"$_title\">{$_attach_messages['btn_info']}</a>]</span>\n";
 			$count = ($showicon && ! empty($this->status['count'][$this->age])) ?
 				sprintf($_attach_messages['msg_count'], $this->status['count'][$this->age]) : '';
 		}
-		return "<a href=\"$script?plugin=attach&amp;pcmd=open$param\" title=\"$title\">$label</a>$count$info";
+		return "<a href=\"$script?plugin=attach&amp;pcmd=open$param\" title=\"$title\">$label</a>$count$info";*/
 	}
 
 	// 情報表示
@@ -634,6 +706,47 @@ class AttachFile
 		}
 		$info = $this->toString(TRUE, FALSE);
 
+		$postScript 	= $script . WikiParam::convQuery("?");
+		$linkList		= $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=list&amp;refer=$r_page");
+		$linkListAll	= $script . WikiParam::convQuery("?plugin=attach&amp;pcmd=list");
+		$retval = array('msg'=>sprintf($_attach_messages['msg_info'], htmlspecialchars($this->file)));
+		$retval['body'] = <<< EOD
+<p class="small">
+ [<a href="$linkList">{$_attach_messages['msg_list']}</a>]
+ [<a href="$linkListAll">{$_attach_messages['msg_listall']}</a>]
+</p>
+<dl>
+ <dt>$info</dt>
+ <dd>{$_attach_messages['msg_page']}:$s_page</dd>
+ <dd>{$_attach_messages['msg_filename']}:{$this->filename}</dd>
+ <dd>{$_attach_messages['msg_md5hash']}:{$this->md5hash}</dd>
+ <dd>{$_attach_messages['msg_filesize']}:{$this->size_str} ({$this->size} bytes)</dd>
+ <dd>Content-type:{$this->type}</dd>
+ <dd>{$_attach_messages['msg_date']}:{$this->time_str}</dd>
+ <dd>{$_attach_messages['msg_dlcount']}:{$this->status['count'][$this->age]}</dd>
+ $msg_freezed
+</dl>
+<hr />
+$s_err
+<form action="$postScript" method="post">
+ <div>
+  <input type="hidden" name="plugin" value="attach" />
+  <input type="hidden" name="refer" value="$s_page" />
+  <input type="hidden" name="file" value="$s_file" />
+  <input type="hidden" name="age" value="{$this->age}" />
+  <input type="hidden" name="pass" />
+  $msg_delete
+  $msg_freeze
+  $msg_rename
+  <br />
+  <label for="_p_attach_password">{$_attach_messages['msg_password']}:</label>
+  <input type="password" name="password" id="_p_attach_password" size="8" />
+  <input type="submit" value="{$_attach_messages['btn_submit']}" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />
+ </div>
+</form>
+EOD;
+
+/*
 		$retval = array('msg'=>sprintf($_attach_messages['msg_info'], htmlspecialchars($this->file)));
 		$retval['body'] = <<< EOD
 <p class="small">
@@ -669,6 +782,7 @@ $s_err
  </div>
 </form>
 EOD;
+*/
 		return $retval;
 	}
 
@@ -706,15 +820,16 @@ EOD;
 			$this->putstatus();
 		}
 
-		if (is_page($this->page))
-			touch(get_filename($this->page));
+		//if (is_page($this->page)) touch(get_filename($this->page));
+		// ページの更新日時を更新
+		if (is_page($this->page)) WikiPage::updatePageTime($this->page);
 
 		if ($notify) {
 			$footer['ACTION']   = 'File deleted';
-			$footer['FILENAME'] = & $this->file;
-			$footer['PAGE']     = & $this->page;
-			$footer['URI']      = get_script_uri() .
-				'?' . rawurlencode($this->page);
+			$footer['FILENAME'] = $this->file;
+			$footer['PAGE']     = $this->page;
+			//$footer['URI']      = get_script_uri() . '?' . rawurlencode($this->page);
+			$footer['URI']      = get_script_uri() . WikiParam::convQuery('?' . rawurlencode($this->page), false);
 			$footer['USER_AGENT']  = TRUE;
 			$footer['REMOTE_ADDR'] = TRUE;
 			pkwk_mail_notify($notify_subject, "\n", $footer) or
@@ -764,6 +879,8 @@ EOD;
 
 	function open()
 	{
+		global $gPageManager;
+
 		$this->getstatus();
 		$this->status['count'][$this->age]++;
 		$this->putstatus();
@@ -786,13 +903,17 @@ EOD;
 		ini_set('default_charset', '');
 		mb_http_output('pass');
 
+		// ページ作成処理中断
+		$gPageManager->abortPage();
+
 		pkwk_common_headers();
 		header('Content-Disposition: inline; filename="' . $filename . '"');
 		header('Content-Length: ' . $this->size);
 		header('Content-Type: '   . $this->type);
-
 		@readfile($this->filename);
-		exit;
+		
+		//ob_end_flush();// for magic3
+		//exit;
 	}
 }
 
@@ -873,7 +994,7 @@ class AttachPages
 
 	function AttachPages($page = '', $age = NULL)
 	{
-
+		// アップロード用のディレクトリ内のファイルリストを取得
 		$dir = opendir(UPLOAD_DIR) or
 			die('directory ' . UPLOAD_DIR . ' is not exist or not readable.');
 
