@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: backup.inc.php 1082 2008-10-16 09:19:43Z fishbone $
+ * @version    SVN: $Id: backup.inc.php 1124 2008-10-25 04:09:51Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -93,7 +93,9 @@ function plugin_backup_action()
 		$body .= ' <li>' . str_replace('$1', $s_page, $_msg_deleted) . "\n";
 	}
 
-	$backups = get_backup($page);
+	//$backups = get_backup($page);
+	$backups = WikiPage::getPageBackupInfo($page);
+	
 	$backups_count = count($backups);
 	if ($s_age > $backups_count) $s_age = $backups_count;
 
@@ -115,28 +117,30 @@ function plugin_backup_action()
 
 	if ($action == 'diff') {
 		$title = & $_title_backupdiff;
-		$old = ($s_age > 1) ? join('', $backups[$s_age - 1]['data']) : '';
-		$cur = join('', $backups[$s_age]['data']);
+		/*$old = ($s_age > 1) ? join('', $backups[$s_age - 1]['data']) : '';
+		$cur = join('', $backups[$s_age]['data']);*/
+		$old = ($s_age > 1) ? WikiPage::getPageBackup($page, $s_age - 1, true) : '';
+		$cur = WikiPage::getPageBackup($page, $s_age, true);
 		$body .= plugin_backup_diff(do_diff($old, $cur));
 	} else if ($s_action == 'nowdiff') {
 		$title = & $_title_backupnowdiff;
-		$old = join('', $backups[$s_age]['data']);
+		//$old = join('', $backups[$s_age]['data']);
+		$old = WikiPage::getPageBackup($page, $s_age, true);
 		$cur = join('', get_source($page));
 		$body .= plugin_backup_diff(do_diff($old, $cur));
 	} else if ($s_action == 'source') {
 		$title = & $_title_backupsource;
-		$body .= '<pre>' . htmlspecialchars(join('', $backups[$s_age]['data'])) .
-			'</pre>' . "\n";
+		//$body .= '<pre>' . htmlspecialchars(join('', $backups[$s_age]['data'])) . '</pre>' . "\n";
+		$body .= '<pre class="wiki_pre">' . htmlspecialchars(WikiPage::getPageBackup($page, $s_age, true)) . '</pre>' . "\n";
 	} else {
 		if (PLUGIN_BACKUP_DISABLE_BACKUP_RENDERING) {
 			die_message('This feature is prohibited');
 		} else {
 			$title = & $_title_backup;
-			$body .= $hr . "\n" .
-				drop_submit(convert_html($backups[$s_age]['data']));
+			//$body .= $hr . "\n" . drop_submit(convert_html($backups[$s_age]['data']));
+			$body .= $hr . "\n" . drop_submit(convert_html(WikiPage::getPageBackup($page, $s_age)));
 		}
 	}
-
 	return array('msg'=>str_replace('$2', $s_age, $title), 'body'=>$body);
 }
 
@@ -218,7 +222,8 @@ $hr
 </ul>
 EOD;
 
-	return $ul . '<pre>' . diff_style_to_css(htmlspecialchars($str)) . '</pre>' . "\n";
+	return $ul . '<pre class="wiki_pre">' . diff_style_to_css(htmlspecialchars($str)) . '</pre>' . "\n";
+	//return $ul . '<pre>' . diff_style_to_css(htmlspecialchars($str)) . '</pre>' . "\n";
 }
 
 function plugin_backup_get_list($page)
@@ -253,7 +258,8 @@ EOD;
  </li>
 </ul>
 EOD;
-	$backups = _backup_file_exists($page) ? get_backup($page) : array();
+	//$backups = _backup_file_exists($page) ? get_backup($page) : array();
+	$backups = WikiPage::isPageBackup($page) ? WikiPage::getPageBackupInfo($page) : array();
 	if (empty($backups)) {
 		$msg = str_replace('$1', make_pagelink($page), $_msg_nobackup);
 		$retval[1] .= '   <li>' . $msg . '</li>' . "\n";
@@ -277,6 +283,7 @@ EOD;
 			$_anchor_to   = '</a>';
 		}
 		$date = format_date($data['time'], TRUE);
+
 		/*$retval[1] .= <<<EOD
    <li>$_anchor_from$age $date$_anchor_to
      [ <a href="$href$age&amp;action=diff">$_msg_diff</a>
