@@ -10,11 +10,11 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: edit.inc.php 1084 2008-10-18 06:10:55Z fishbone $
+ * @version    SVN: $Id: edit.inc.php 1098 2008-10-22 11:43:09Z fishbone $
  * @link       http://www.magic3.org
  */
 // PukiWiki - Yet another WikiWikiWeb clone.
-// $Id: edit.inc.php 1084 2008-10-18 06:10:55Z fishbone $
+// $Id: edit.inc.php 1098 2008-10-22 11:43:09Z fishbone $
 // Copyright (C) 2001-2006 PukiWiki Developers Team
 // License: GPL v2 or (at your option) any later version
 
@@ -87,14 +87,16 @@ function plugin_edit_preview()
 
 		// Cut fixed anchors
 		$msg = preg_replace('/^(\*{1,3}.*)\[#[A-Za-z][\w-]+\](.*)$/m', '$1$2', $msg);
-		WikiParam::setMsg($msg);
+//		WikiParam::setMsg($msg);		// tmp
+	} else {
+		$msg = WikiParam::getMsg();
 	}
 
 	/*$vars['msg'] = preg_replace(PLUGIN_EDIT_FREEZE_REGEX, '', $vars['msg']);
 	$postdata = $vars['msg'];*/
-	$msg = WikiParam::getMsg();
-	//$msg = preg_replace(PLUGIN_EDIT_FREEZE_REGEX, '', $msg);		// removed for magic3
-	WikiParam::setMsg($msg);
+//	$msg = WikiParam::getMsg();			// tmp
+	//$msg = preg_replace(PLUGIN_EDIT_FREEZE_REGEX, '', $msg);		// not use freeze expression removed by magic3
+//	WikiParam::setMsg($msg);		// tmp
 	$postdata = $msg;
 	
 	//if (isset($vars['add']) && $vars['add']) {
