@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_youtubeWidgetContainer.php 924 2008-08-22 08:56:24Z fishbone $
+ * @version    SVN: $Id: admin_youtubeWidgetContainer.php 961 2008-08-30 09:14:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
@@ -166,7 +166,7 @@ class admin_youtubeWidgetContainer extends BaseWidgetContainer
 				} else {
 					$this->setAppErrorMsg('データ追加に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		} else if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
@@ -201,13 +201,12 @@ class admin_youtubeWidgetContainer extends BaseWidgetContainer
 					
 					if (empty($defConfigId)){		// 画面定義の定義IDが設定されていないときは設定
 						$defConfigId = $this->configId;		// 定義定義IDを更新
-						$gPageManager->updateParentWindow();// 親ウィンドウを更新
 					}
 					$replaceNew = true;			// データ再取得
 				} else {
 					$this->setMsg(self::MSG_APP_ERR, 'データ更新に失敗しました');
 				}
-				$gPageManager->updateParentWindow();// 親ウィンドウを更新
+				$gPageManager->updateParentWindow($defSerial);// 親ウィンドウを更新
 			}
 		} else if ($act == 'select'){	// 定義IDを変更
 			$replaceNew = true;			// データ再取得
